==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001_result/GRIDRESULT.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}DATASPY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}TOOLBAR"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}GRID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}FUNCTION_REQUEST_TYPE" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dataspy",
    "toolbar",
    "grid"
})
@XmlRootElement(name = "GRIDRESULT")
public class GRIDRESULT {

    @XmlElement(name = "DATASPY", required = true)
    protected DATASPY dataspy;
    @XmlElement(name = "TOOLBAR", required = true)
    protected TOOLBAR toolbar;
    @XmlElement(name = "GRID", required = true)
    protected GRID grid;
    @XmlAttribute(name = "type")
    protected FUNCTION_REQUEST_TYPE type;

    /**
     * Obtient la valeur de la propriété dataspy.
     * 
     * @return
     *     possible object is
     *     {@link DATASPY }
     *     
     */
    public DATASPY getDATASPY() {
        return dataspy;
    }

    /**
     * Définit la valeur de la propriété dataspy.
     * 
     * @param value
     *     allowed object is
     *     {@link DATASPY }
     *     
     */
    public void setDATASPY(DATASPY value) {
        this.dataspy = value;
    }

    /**
     * Obtient la valeur de la propriété toolbar.
     * 
     * @return
     *     possible object is
     *     {@link TOOLBAR }
     *     
     */
    public TOOLBAR getTOOLBAR() {
        return toolbar;
    }

    /**
     * Définit la valeur de la propriété toolbar.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLBAR }
     *     
     */
    public void setTOOLBAR(TOOLBAR value) {
        this.toolbar = value;
    }

    /**
     * Obtient la valeur de la propriété grid.
     * 
     * @return
     *     possible object is
     *     {@link GRID }
     *     
     */
    public GRID getGRID() {
        return grid;
    }

    /**
     * Définit la valeur de la propriété grid.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID }
     *     
     */
    public void setGRID(GRID value) {
        this.grid = value;
    }

    /**
     * Obtient la valeur de la propriété type.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public FUNCTION_REQUEST_TYPE getType() {
        return type;
    }

    /**
     * Définit la valeur de la propriété type.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public void setType(FUNCTION_REQUEST_TYPE value) {
        this.type = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001_result/GRIDRESULT.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}DATASPY"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}TOOLBAR"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}GRID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="type" type="{http://schemas.datastream.net/MP_functions/MP0118_GetGridHeaderData_001_Result}FUNCTION_REQUEST_TYPE" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dataspy",
    "toolbar",
    "grid"
})
@XmlRootElement(name = "GRIDRESULT")
public class GRIDRESULT {

    @XmlElement(name = "DATASPY", required = true)
    protected DATASPY dataspy;
    @XmlElement(name = "TOOLBAR", required = true)
    protected TOOLBAR toolbar;
    @XmlElement(name = "GRID", required = true)
    protected GRID grid;
    @XmlAttribute(name = "type")
    protected FUNCTION_REQUEST_TYPE type;

    /**
     * Gets the value of the dataspy property.
     * 
     * @return
     *     possible object is
     *     {@link DATASPY }
     *     
     */
    public DATASPY getDATASPY() {
        return dataspy;
    }

    /**
     * Sets the value of the dataspy property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATASPY }
     *     
     */
    public void setDATASPY(DATASPY value) {
        this.dataspy = value;
    }

    /**
     * Gets the value of the toolbar property.
     * 
     * @return
     *     possible object is
     *     {@link TOOLBAR }
     *     
     */
    public TOOLBAR getTOOLBAR() {
        return toolbar;
    }

    /**
     * Sets the value of the toolbar property.
     * 
     * @param value
     *     allowed object is
     *     {@link TOOLBAR }
     *     
     */
    public void setTOOLBAR(TOOLBAR value) {
        this.toolbar = value;
    }

    /**
     * Gets the value of the grid property.
     * 
     * @return
     *     possible object is
     *     {@link GRID }
     *     
     */
    public GRID getGRID() {
        return grid;
    }

    /**
     * Sets the value of the grid property.
     * 
     * @param value
     *     allowed object is
     *     {@link GRID }
     *     
     */
    public void setGRID(GRID value) {
        this.grid = value;
    }

    /**
     * Gets the value of the type property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public FUNCTION_REQUEST_TYPE getType() {
        return type;
    }

    /**
     * Sets the value of the type property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTION_REQUEST_TYPE }
     *     
     */
    public void setType(FUNCTION_REQUEST_TYPE value) {
        this.type = value;
    }

}
